@@ -9,7 +9,7 @@ class_has Actions => (
     default => sub {{
         'namespaces' => [qw(create update delete list control)],
         'tags'       => [qw(update delete control)],
-        'tag-values' => [qw(see create read delete control)]
+        'tag-values' => [qw(create read delete control)]
     }}
 );
 
@@ -101,7 +101,7 @@ Xavier Noria (FXN), E<lt>fxn@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 Xavier Noria
+Copyright (C) 2009-2011 Xavier Noria
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
