@@ -29,7 +29,7 @@ sub create {
         payload    => $payload,
         on_success => sub {
             my $response = shift;
-            my $h = $self->json->decode($response->content);        
+            my $h = $self->json->decode($response->content);
             $self->_set_id($h->{id});
             # Unset tag paths to force fetching the about tag.
             $self->_set_tag_paths(['fluiddb/about']) if $self->has_about;
@@ -39,6 +39,11 @@ sub create {
 }
 
 sub get {
+    print STDERR "get has been deprecated and will be removed, please use get_by_id instead\n";
+    &get_by_id;
+}
+
+sub get_by_id {
     my ($class, $fdb, $id, %opts) = @_;
 
     $opts{showAbout} = $class->true if delete $opts{about};
@@ -52,14 +57,26 @@ sub get {
             my $o = $class->new(fdb => $fdb, %$h);
             $o->_set_id($id);
             $o->_set_tag_paths($h->{tagPaths});
-            $o;            
+            $o;
         }
     );
 }
 
 sub get_by_about {
     my ($class, $fdb, $about) = @_;
-    # TODO: implement it
+    $fdb->get(
+        path       => $class->abs_path('/about', $about),
+        headers    => $fdb->accept_header_for_json,
+        on_success => sub {
+            my $response = shift;
+            my $h = $class->json->decode($response->content);
+            my $o = $class->new(fdb => $fdb);
+            $o->_set_id($h->{id});
+            $o->_set_tag_paths($h->{tagPaths});
+            $o->about($about);
+            $o;
+        }
+    );
 }
 
 sub search {
@@ -90,6 +107,28 @@ sub tag {
     }
 }
 
+sub has_tag {
+    my ($class, $fdb, $object_id, $tag_or_tag_path) = @_;
+
+    my $tag_path = $class->get_tag_path_from_tag_or_tag_path($tag_or_tag_path);
+    $fdb->head(
+        path       => $class->abs_path('/objects', $object_id, $tag_path),
+        on_success => sub { 1 },
+        on_failure => sub {
+            my $response = shift;
+
+            if ($response->code == 404) {
+                0;
+            } else {
+                # Can be a 401 if permissions disallow this test. Do this as we
+                # do elsewhere until we get proper support for failures.
+                print STDERR $response->as_string;
+                0;
+            }
+        }
+    );
+}
+
 sub tag_fdb_value_or_scalar {
     my ($self, $tag_path, $value) = @_;
 
@@ -115,7 +154,7 @@ sub tag_fdb_value_or_scalar_with_options {
     my ($self, $tag_path, $type, $value) = @_;
 
     my $native_type = Net::FluidDB::Value::Native->type_from_alias($type);
-    $value = $native_type ? 
+    $value = $native_type ?
              $native_type->new(value => $value) :
              Net::FluidDB::Value::NonNative->new(value => $value, mime_type => $type);
     $self->tag_fdb_value($tag_path, $value);
@@ -123,7 +162,7 @@ sub tag_fdb_value_or_scalar_with_options {
 
 sub tag_fdb_value {
     my ($self, $tag_path, $value) = @_;
-    
+
     my $status = $self->fdb->put(
         path    => $self->abs_path('objects', $self->id, $tag_path),
         headers => {'Content-Type' => $value->mime_type},
@@ -134,16 +173,16 @@ sub tag_fdb_value {
         push @{$self->tag_paths}, $tag_path;
     }
 
-    $status;    
+    $status;
 }
 
 sub value {
     my ($self, $tag_or_tag_path, @rest) = @_;
     my $list_context = wantarray;
-    
+
     my $tag_path = $self->get_tag_path_from_tag_or_tag_path($tag_or_tag_path);
     $self->fdb->get(
-        path => $self->abs_path('objects', $self->id, $tag_path),
+        path       => $self->abs_path('objects', $self->id, $tag_path),
         on_success => sub {
             my $response = shift;
             my $value_object = Net::FluidDB::Value->new_from_mime_type_and_content(
@@ -156,7 +195,7 @@ sub value {
 }
 
 sub get_tag_path_from_tag_or_tag_path {
-    my ($self, $tag_or_tag_path) = @_;
+    my $tag_or_tag_path = $_[1];
     ref($tag_or_tag_path) ? $tag_or_tag_path->path : $tag_or_tag_path;
 }
 
@@ -204,10 +243,13 @@ Net::FluidDB::Object - FluidDB objects
      about => $unique_about
  );
  $object->create;
- $object->id; # returns the object's ID in FluidDB 
- 
+ $object->id; # returns the object's ID in FluidDB
+
  # get by ID, optionally fetching about
- $object = Net::FluidDB::Object->get($fdb, $object_id, about => 1);
+ $object = Net::FluidDB::Object->get_by_id($fdb, $id, about => 1);
+
+ # get by about
+ $object = Net::FluidDB::Object->get_by_about($fdb, $about);
 
  # tag
  $object->tag("fxn/likes");
@@ -216,16 +258,16 @@ Net::FluidDB::Object - FluidDB objects
 
  # retrieve a tag value
  $value = $object->value("fxn/rating");
- 
+
  # retrieve a tag value and its type
  ($type, $value) = $object->value("fxn/rating");
- 
+
  # remove a tag
  $object->untag("fxn/rating");
 
  # search
  @ids = Net::FluidDB::Object->search($fdb, "has fxn/rating");
- 
+
 =head1 DESCRIPTION
 
 C<Net::FluidDB::Object> models FluidDB objects.
@@ -257,9 +299,9 @@ A string, if any.
 =back
 
 This constructor is only useful for creating new objects in FluidDB.
-Already existing objects are fetched with C<get>.
+Already existing objects are fetched with C<get_by_id> or C<get_by_about>:
 
-=item Net::FluidDB::Object->get($fdb, $id, %opts)
+=item Net::FluidDB::Object->get_by_id($fdb, $id, %opts)
 
 Retrieves the object with ID C<$id> from FluidDB. Options are:
 
@@ -276,6 +318,12 @@ has an about attribute in FluidDB.
 
 C<Net::FluidDB> provides a convenience shortcut for this method.
 
+=item Net::FluidDB::Object->get_by_about($fdb, $about)
+
+Retrieves the object with about C<$about> from FluidDB.
+
+C<Net::FluidDB> provides a convenience shortcut for this method.
+
 =item Net::FluidDB::Object->search($fdb, $query)
 
 Performs the query C<$query> and returns a (possibly empty) array of strings with
@@ -283,6 +331,17 @@ the IDs of the macthing objects.
 
 C<Net::FluidDB> provides a convenience shortcut for this method.
 
+=item Net::FluidDB::Object->has_tag($fdb, $object_id, $tag_or_tag_path)
+
+When you retrieve an object from FluidDB the instance has the paths
+of its tags as an attribute. But if you only have an object ID and
+are interested in checking whether the corresponding object has been
+tagged with a certain tag, this predicate is cheaper than fetching
+the object.
+
+You can pass either a L<Net::FluidDB::Tag> instance or a tag path
+in the rightmost argument.
+
 =back
 
 =head2 Instance Methods
@@ -410,7 +469,7 @@ Xavier Noria (FXN), E<lt>fxn@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 Xavier Noria
+Copyright (C) 2009-2011 Xavier Noria
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
